<?php
/*
Plugin Name: Theme to Browser (T2B) Control
Plugin URI: http://www.federicojacobi.com/wp/work/t2b-control/
Description: Display a different theme depending on the users browser. It is perfect for a quick way out of CSS annoyances and also for customization on mobile devices. Supports: Internet Explorer, FireFox, Opera, iPhone/iPod, iPad, Safari, BlackBerries, Playstation 3
Version: 0.3
Author: Federico Jacobi
Author URI: http://www.federicojacobi.com
*/

$supported_browsers = array (
	'|MSIE ([0-9].[0-9]{1,2})|' => array('ie','Internet Explorer'),
	'|Firefox/([0-9\.]+)|' => array('firefox','FireFox'),
	'|Opera/([0-9].[0-9]{1,2})|' => array('opera','Opera'),
	'/\(iPhone|iPod/' => array('iphone','iPhone, iPod'),
	'/\(iPad/' => array('ipad','iPad'),
	'|Safari/([0-9\.]+)|' => array('safari','Safari'),
	'/BlackBerry8310/' => array('blackberry8310','BlackBerry 8310'),
	'/BlackBerry/' => array('blackberry','All BlackBerry'),
	'/PLAYSTATION 3|PS3/' => array('ps3','Playstation 3')
);
$lzt_version = '0.3';
$useragent = $_SERVER['HTTP_USER_AGENT'];
$browser_version = 0;
$lzt_browser= 'default';

foreach ($supported_browsers as $browser_regex => $browser_name) {
	if (preg_match($browser_regex,$useragent,$matched)) {
		$browser_version=$matched[1];
		$lzt_browser = $browser_name[0];
		break;
	}
}

$lzt_theme = get_option('lzt_'.$lzt_browser);

if ($lzt_theme != "t2b_default") {
	// Check for a valid theme directory, and set the template and stylesheet directory
	if($lzt_theme && file_exists(get_theme_root() . "/$lzt_theme")) {
	
		$theme_data = get_theme_data(get_theme_root()."/$lzt_theme/style.css");
		if ($theme_data['Template'] == '') {
			$theme_parent = $lzt_theme;
		} else {
			$theme_parent = $theme_data['Template'];
		}
		add_filter('template','lzt_set_theme');
		add_filter('stylesheet','lzt_set_css');
	//	add_action('wp_footer','echoresult');	// Triggers debug at the footer
	}
}

// Debug function ... just to make sure the right stuff is loaded
function echoresult() {
	global $theme_parent, $lzt_theme;
	global $theme_data;
	echo "ThemeParent:".$theme_parent."<br>";
	echo "ThemeCss:".$lzt_theme;	
}


function lzt_set_theme() {
	global $theme_parent;
	return $theme_parent;
}
function lzt_set_css() {
	global $lzt_theme;
	return $lzt_theme;
}

function admin_lazy_theme_options() {
	global $supported_browsers, $lzt_version;
	?>
    <div class="wrap">
    <h2>Theme to Browser Control a.k.a. T2B (v.<?php echo $lzt_version ?>)</h2>
    <?php
	if ($_REQUEST['submit']) {
		update_lzt_options();
	}
	?>
    <p>Select the desired theme to show for the respective browser. </p>
    <p>Supported browsers: <?php
	
	foreach ($supported_browsers as $browser_regex => $browser_name) {
		echo $browser_name[1].', ';
	}
	?></p>
	<?php
	print_lzt_form();
	?>
    </div>
    <?
}

function update_lzt_options() {
	global $supported_browsers;
	foreach ($supported_browsers as $browser_regex => $browser_name) {
		if ($_REQUEST[$browser_name[0]])
			update_option('lzt_'.$browser_name[0],$_REQUEST[$browser_name[0]]);
	}
	echo '<div id="message" class="updated fade">
	<p>Options have been saved. Please test!! if the plugin is not detecting your browser, please let me know at web@federicojacobi.com</p>
	</div>';
}

function print_lzt_form() {
	global $supported_browsers;
	$first = false;
	?>
		<form action="" method="post">
            	<?php
					foreach ($supported_browsers as $browser_regex => $browser_name) {
				?>
			<div class="postbox" style="width:200px; float:left; display: inline-block; margin: 5px;">
            	<h3 class="hndle"><span><?php echo $browser_name[1] ?></span></h3>
                <div class="inside"><p><ul>
				<?php 
					$themes = get_themes();
					if (get_option('lzt_'.$browser_name[0]) == '')
						$first = true;
					?>
                    <li><input type="radio" name="<?php echo $browser_name[0]?>" value="t2b_default" <?php 
					// IF este es el seleccionado THEN echo SELECTED
					if ((get_option('lzt_'.$browser_name[0]) == "t2b_default") || ($first)) {
						echo 'checked="checked"';
						$first = false;
					}
					?> /> Default theme</li>
                    <?php
					foreach($themes as $theme) {
				?>
				<li><input type="radio" name="<?php echo $browser_name[0]?>" value="<?php echo $theme['Stylesheet']; ?>" <?php 
					// IF este es el seleccionado THEN echo SELECTED
					if ((get_option('lzt_'.$browser_name[0]) == $theme['Stylesheet']) || ($first)) {
						echo 'checked="checked"';
						$first = false;
					}
					?> /> <?php echo htmlentities($theme['Title']); ?></li>
				<?php
					}
				
				?></ul></p>
                </div>
			</div>
                <?php
					}
				?>
			<div style="clear:both;"></div>
			<input type="submit" name="submit" value="<?php _e("Save Settings"); ?>" class='button-primary' />
		</form>
    
    <?php
}

function lzt_modify_menu() {
	add_theme_page(
		'T2B Control',
		"T2B Control",
		'manage_options',
		__FILE__,
		'admin_lazy_theme_options'
	);
}

function set_lazy_theme_options() {
	global $supported_browsers;
	foreach ($supported_browsers as $browser_regex => $browser_name) {
		add_option('lzt_'.$browser_name[0],'');
	}
}

function unset_lazy_theme_options() {
	global $supported_browsers;
	foreach ($supported_browsers as $browser_regex => $browser_name) {
		delete_option('lzt_'.$browser_name[0]);
	}
}


add_action('admin_menu','lzt_modify_menu');

register_activation_hook(__FILE__,'set_lazy_theme_options');
register_deactivation_hook(__FILE__,'unset_lazy_theme_options');
?>